==> haskell-auto-update-0.1.6-161-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-auto-update.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 auto-update
version:              0.1.6
visibility:           public
id:                   auto-update-0.1.6-F49wuFItZe7AOsoVGTJ1vM
key:                  auto-update-0.1.6-F49wuFItZe7AOsoVGTJ1vM
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/yesodweb/wai
synopsis:             Efficiently run periodic, on-demand actions
description:
    API docs and the README are available at <http://www.stackage.org/package/auto-update>.

category:             Control
abi:                  cf8bd6ac8256800b9198f5ffbdc557a7
exposed:              True
exposed-modules:
    Control.AutoUpdate Control.Debounce Control.Debounce.Internal
    Control.Reaper

hidden-modules:       Control.AutoUpdate.Util
import-dirs:          /usr/lib/ghc-8.10.4/site-local/auto-update-0.1.6
library-dirs:         /usr/lib/ghc-8.10.4/site-local/auto-update-0.1.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/auto-update-0.1.6
hs-libraries:         HSauto-update-0.1.6-F49wuFItZe7AOsoVGTJ1vM
depends:              base-4.14.1.0
haddock-interfaces:   /usr/share/doc/haskell-auto-update/html/auto-update.haddock
haddock-html:         /usr/share/doc/haskell-auto-update/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-auto-update-0.1.6-163-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-auto-update.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 auto-update
version:              0.1.6
visibility:           public
id:                   auto-update-0.1.6-1hwtdrc4ThnKbqSR25KBM0
key:                  auto-update-0.1.6-1hwtdrc4ThnKbqSR25KBM0
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/yesodweb/wai
synopsis:             Efficiently run periodic, on-demand actions
description:
    API docs and the README are available at <http://www.stackage.org/package/auto-update>.

category:             Control
abi:                  5a440fe55aeb0da1b40856a4471cf6f9
exposed:              True
exposed-modules:
    Control.AutoUpdate Control.Debounce Control.Debounce.Internal
    Control.Reaper

hidden-modules:       Control.AutoUpdate.Util
import-dirs:          /usr/lib/ghc-8.10.4/site-local/auto-update-0.1.6
library-dirs:         /usr/lib/ghc-8.10.4/site-local/auto-update-0.1.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/auto-update-0.1.6
hs-libraries:         HSauto-update-0.1.6-1hwtdrc4ThnKbqSR25KBM0
depends:              base-4.14.1.0
haddock-interfaces:   /usr/share/doc/haskell-auto-update/html/auto-update.haddock
haddock-html:         /usr/share/doc/haskell-auto-update/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
